@@ -34,7 +34,7 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('barbican/barbican_api_version').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/max_concurrent_live_migrations').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('pci/passthrough_whitelist').with(:value => '<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('compute/consecutive_build_service_disable_threshold').with_value('<SERVICE DEFAULT>') }
 
       it { is_expected.to_not contain_package('cryptsetup').with( :ensure => 'present' )}
 
@@ -60,6 +60,11 @@ describe 'nova::compute' do
         is_expected.to contain_package('genisoimage').that_requires('Anchor[nova::install::begin]')
         is_expected.to contain_package('genisoimage').that_comes_before('Anchor[nova::install::end]')
       end
+
+      it 'configures nova pci_passthrough_whitelist' do
+        is_expected.to contain_class('nova::compute::pci')
+        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(:value => '<SERVICE DEFAULT>')
+      end
     end
 
     context 'with overridden parameters' do
@@ -79,6 +84,7 @@ describe 'nova::compute' do
           :barbican_api_version               => 'v1',
           :barbican_auth_endpoint             => 'http://127.0.0.1:5000/v3',
           :max_concurrent_live_migrations     => '4',
+          :consecutive_build_service_disable_threshold => '9',
         }
       end
 
@@ -128,6 +134,8 @@ describe 'nova::compute' do
 
       it { is_expected.to contain_nova_config('DEFAULT/max_concurrent_live_migrations').with_value('4') }
 
+      it { is_expected.to contain_nova_config('compute/consecutive_build_service_disable_threshold').with_value('9') }
+
       it { is_expected.to contain_nova_config('DEFAULT/resume_guests_state_on_host_boot').with_value(true) }
 
       it 'configures nova config_drive_format to vfat' do
@@ -138,7 +146,7 @@ describe 'nova::compute' do
       end
     end
 
-    context 'with pci_passthrough array' do
+    context 'with pci params array' do
       let :params do
         {
           :pci_passthrough => [
@@ -151,41 +159,44 @@ describe 'nova::compute' do
               "product_id"       => "1520",
               "physical_network" => "physnet1"
             }
-          ]
+          ],
         }
       end
 
       it 'configures nova pci_passthrough_whitelist entries' do
+        is_expected.to contain_class('nova::compute::pci')
         is_expected.to contain_nova_config('pci/passthrough_whitelist').with(
           'value' => ['{"vendor_id":"8086","product_id":"0126"}','{"vendor_id":"9096","product_id":"1520","physical_network":"physnet1"}']
         )
       end
     end
 
-    context 'with pci_passthrough JSON encoded string (deprecated)' do
+    context 'with pci params JSON encoded string (deprecated)' do
       let :params do
         {
-          :pci_passthrough => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"physical_network\":\"physnet1\"}]"
+          :pci_passthrough => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"physical_network\":\"physnet1\"}]",
         }
       end
 
       it 'configures nova pci_passthrough_whitelist entries' do
+        is_expected.to contain_class('nova::compute::pci')
         is_expected.to contain_nova_config('pci/passthrough_whitelist').with(
           'value' => ['{"vendor_id":"8086","product_id":"0126"}','{"vendor_id":"9096","product_id":"1520","physical_network":"physnet1"}']
         )
       end
     end
 
-    context 'when vcpu_pin_set and pci_passthrough are empty' do
+    context 'when vcpu_pin_set and pci params are empty' do
       let :params do
         { :vcpu_pin_set    => "",
-          :pci_passthrough => "" }
+          :pci_passthrough => ""}
       end
 
       it 'clears vcpu_pin_set configuration' do
         is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:value => '<SERVICE DEFAULT>')
       end
       it 'clears pci_passthrough configuration' do
+        is_expected.to contain_class('nova::compute::pci')
         is_expected.to contain_nova_config('pci/passthrough_whitelist').with(:value => '<SERVICE DEFAULT>')
       end
     end
