@@ -98,6 +98,7 @@ describe 'nova' do
           :notification_transport_url              => 'rabbit://rabbit_user:password@localhost:5673',
           :notification_driver                     => 'ceilometer.compute.nova_notifier',
           :notification_topics                     => 'openstack',
+          :notification_format                     => 'unversioned',
           :notify_api_faults                       => true,
           :report_interval                         => '60',
           :os_region_name                          => 'MyRegion',
@@ -114,6 +115,7 @@ describe 'nova' do
           :purge_config                            => false,
           :block_device_allocate_retries           => '60',
           :block_device_allocate_retries_interval  => '3',
+          :my_ip                                   => '192.0.2.1',
         }
       end
 
@@ -155,6 +157,10 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/host').with_value('test-001.example.org')
       end
 
+      it 'configures my_ip' do
+        is_expected.to contain_nova_config('DEFAULT/my_ip').with_value('192.0.2.1')
+      end
+
       it 'configures upgrade_levels' do
         is_expected.to contain_nova_config('upgrade_levels/cells').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/cert').with_value('1.0.0')
@@ -175,6 +181,7 @@ describe 'nova' do
         is_expected.to contain_nova_config('oslo_messaging_notifications/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
         is_expected.to contain_nova_config('oslo_messaging_notifications/driver').with_value('ceilometer.compute.nova_notifier')
         is_expected.to contain_nova_config('oslo_messaging_notifications/topics').with_value('openstack')
+        is_expected.to contain_nova_config('notifications/notification_format').with_value('unversioned')
         is_expected.to contain_nova_config('notifications/notify_api_faults').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('60')
         is_expected.to contain_nova_config('os_vif_linux_bridge/use_ipv6').with_value('true')
